@@ -1,21 +1,18 @@
-#line 1 "inc/Sort/Versions.pm - /Library/Perl/5.8.1/Sort/Versions.pm"
-#!/usr/bin/perl
-
-# $Id: Versions.pm,v 1.9 2003/08/24 22:58:14 ed Exp $
-
+#line 1
+package Sort::Versions;
+$Sort::Versions::VERSION = '1.60';
 # Copyright (c) 1996, Kenneth J. Albanowski. All rights reserved.  This
 # program is free software; you can redistribute it and/or modify it under
 # the same terms as Perl itself.
 
-package Sort::Versions;
-use vars '$VERSION';
-$VERSION = '1.5';
+use 5.006;
+use strict;
+use warnings;
 
 require Exporter;
-@ISA=qw(Exporter);
-
-@EXPORT=qw(&versions &versioncmp);
-@EXPORT_OK=qw();
+our @ISA        = qw(Exporter);
+our @EXPORT     = qw(&versions &versioncmp);
+our @EXPORT_OK  = qw();
 
 sub versioncmp( $$ ) {
     my @A = ($_[0] =~ /([-.]|\d+|[^-.\d]+)/g);
@@ -60,7 +57,9 @@ sub versions() {
     return versioncmp($$caller_a, $$caller_b);
 }
 
-#line 149
+
+
+#line 159
 
 1;
 
